from mygrad import tanh

from .hard_tanh import hard_tanh
from .relu import relu
from .sigmoid import sigmoid
from .softmax import logsoftmax, softmax

__all__ = ["hard_tanh", "logsoftmax", "relu", "sigmoid", "softmax", "tanh"]



from .margin_ranking_loss import margin_ranking_loss
from .multiclass_hinge import multiclass_hinge
from .softmax_crossentropy import softmax_crossentropy

__all__ = ["margin_ranking_loss", "multiclass_hinge", "softmax_crossentropy"]
